@@ -35,7 +35,9 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
 #include "xf86Resources.h"
+#endif
 #include "xf86cmap.h"
 #include "compiler.h"
 #include "mipointer.h"
@@ -73,14 +75,6 @@
 
 extern OptionInfoRec GX_GeodeOptions[];
 
-extern const char *amdVgahwSymbols[];
-extern const char *amdVbeSymbols[];
-extern const char *amdInt10Symbols[];
-extern const char *amdFbSymbols[];
-extern const char *amdXaaSymbols[];
-extern const char *amdExaSymbols[];
-extern const char *amdRamdacSymbols[];
-
 unsigned char *XpressROMPtr;
 
 static inline void
@@ -427,8 +421,10 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	return FALSE;
 
     pEnt = xf86GetEntityInfo(pScrni->entityList[0]);
+#ifndef XSERVER_LIBPCIACCESS
     if (pEnt->resources)
 	return FALSE;
+#endif
 
     pGeode = pScrni->driverPrivate = xnfcalloc(sizeof(GeodeRec), 1);
 
@@ -515,7 +511,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
     pGeode->tryCompression = TRUE;
 
     pGeode->NoAccel = FALSE;
-    pGeode->useEXA = TRUE;
+    pGeode->useEXA = FALSE;
 
     pGeode->Panel = (pGeode->Output & OUTPUT_PANEL) ? TRUE : FALSE;
 
@@ -586,7 +582,7 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	    pGeode->useEXA = FALSE;
 	else if (xf86NameCmp(s, "EXA"))
 	    xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
-		"Unknown accleration method %s.  Defaulting to EXA.\n", s);
+		"Unknown accleration method %s.  Defaulting to XAA.\n", s);
     }
 
     xf86DrvMsg(pScrni->scrnIndex, X_INFO,
@@ -622,7 +618,6 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 
 	if (!xf86LoadSubModule(pScrni, "int10"))
 	    return FALSE;
-	xf86LoaderReqSymLists(amdInt10Symbols, NULL);
 
 	pVesa = pGeode->vesa;
 
@@ -699,34 +694,27 @@ GXPreInit(ScrnInfoPtr pScrni, int flags)
 	return FALSE;
     }
 
-    xf86LoaderReqSymLists(amdFbSymbols, NULL);
-
     if (pGeode->NoAccel == FALSE) {
 	const char *module = (pGeode->useEXA) ? "exa" : "xaa";
-	const char **symbols = (pGeode->useEXA) ?
-	    &amdExaSymbols[0] : &amdXaaSymbols[0];
 
 	if (!xf86LoadSubModule(pScrni, module)) {
 	    return FALSE;
 	}
-
-	xf86LoaderReqSymLists(symbols, NULL);
     }
 
     if (pGeode->tryHWCursor == TRUE) {
 	if (!xf86LoadSubModule(pScrni, "ramdac")) {
 	    return FALSE;
 	}
-
-	xf86LoaderReqSymLists(amdRamdacSymbols, NULL);
     }
 
+#ifndef XSERVER_LIBPCIACCESS
     if (xf86RegisterResources(pGeode->pEnt->index, NULL, ResExclusive)) {
 	xf86DrvMsg(pScrni->scrnIndex, X_ERROR,
 	    "Couldn't register the resources.\n");
 	return FALSE;
     }
-
+#endif
     return TRUE;
 }
 
@@ -1250,7 +1238,7 @@ GXScreenInit(int scrnIndex, ScreenPtr pScrn, int argc, char **argv)
 
 	if (pGeode->useEXA) {
 
-	    if (!(pGeode->pExa = xnfcalloc(sizeof(ExaDriverRec), 1))) {
+	    if (!(pGeode->pExa = exaDriverAlloc())) {
 		xf86DrvMsg(scrnIndex, X_ERROR,
 		    "Couldn't allocate the EXA structure.\n");
 		pGeode->NoAccel = TRUE;
